@@ -4,10 +4,8 @@ $lang['helpshowall'] = 'Visa alla artiklar, oavsett slutdatum';
 $lang['error_invaliddates'] = 'Ett eller flera av datumen som skrevs in &auml;r ogiltigt';
 $lang['notify_n_draft_items_sub'] = '%d nyhetsartikel/-artiklar';
 $lang['notify_n_draft_items'] = 'Du har <a href="moduleinterface.php?module=News">%d nyhetsartiklar</a> som inte har publicerats';
-$lang['helprsscategory'] = 'Att anv&auml;nda tillsammans med parametern makerssbutton. G&ouml;r det m&ouml;jligt att specificera en enskild kategori att anv&auml;nda i rss-str&ouml;mmen';
 $lang['unlimited'] = 'Obegr&auml;nsad';
 $lang['none'] = 'Ingen';
-$lang['rss_destinationpage'] = 'Sid ID eller alias f&ouml;r m&aring;lsidan f&ouml;r RSS';
 $lang['anonymous'] = 'Anonym';
 $lang['unknown'] = 'Ok&auml;nd';
 $lang['fesubmit_redirect'] = 'Sid ID eller alias att &aring;terg&aring; till efter att en nyhetsartikel har blivit tillagd med &quot;fesubmit&quot; funktionen';
@@ -153,8 +151,6 @@ $lang['numbertodisplay'] = 'Max antal nyheter som ska visas (om tomt visas alla)
 $lang['print'] = 'Skriv ut';
 $lang['postdate'] = 'Publiceringsdatum';
 $lang['postinstall'] = 'Kom ih&aring;g att s&auml;tta r&auml;ttigheten &quot;Modify News&quot; f&ouml;r de anv&auml;ndare som ska administrera nyhetsartiklar.';
-$lang['rssfeedtitle'] = 'CMS Made Simple RSS-str&ouml;m';
-$lang['rsstemplate'] = 'RSS-mall';
 $lang['selectcategory'] = 'V&auml;lj kategori';
 $lang['showchildcategories'] = 'Visa underkategorier';
 $lang['sortascending'] = 'Sortera stigande';
@@ -169,8 +165,6 @@ $lang['title'] = 'Titel';
 $lang['options'] = 'Inst&auml;llningar';
 $lang['optionsupdated'] = 'Inst&auml;llningarna har uppdaterats.';
 $lang['useexpiration'] = 'Anv&auml;nd stoppdatum';
-$lang['showautodiscovery'] = 'Visa Auto Discovery-l&auml;nk f&ouml;r RSS-str&ouml;m';
-$lang['autodiscoverylink'] = 'URL f&ouml;r Auto Discovery-str&ouml;m (l&auml;mna tom f&ouml;r standard)';
 $lang['eventdesc-NewsArticleAdded'] = 'Skickas n&auml;r en artikel l&auml;ggs till.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Skickas n&auml;r en artikel l&auml;ggs till.</p>
 <h4>Parametrar</h4>
@@ -232,9 +226,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Skickas n&auml;r en kategori tas bo
 <li>\&quot;name\&quot; - Namnet p&aring; kategorin som togs bort</li>
 </ul>
 ';
+$lang['help_articleid'] = 'Denna parameter fungerar endast i den detaljerade vyn. Den till&aring;ter att specificera vilken nyhetsartikel som visas i detaljerad vy. Om specialv&auml;rdet -1 anv&auml;nds, visar systemet den nyaste, publicerade, ej utg&aring;ngna artikeln.';
 $lang['helpnumber'] = 'Max antal artiklar att visa (om tomt visas alla artiklar).';
 $lang['helpstart'] = 'B&ouml;rja fr&aring;n nyhet nummer X -- om l&auml;mnas tom visas fr&aring;n f&ouml;rsta nyheten.';
-$lang['helpmakerssbutton'] = 'Skapar en klickbar knapp som l&auml;nkar till en RSS-str&ouml;m f&ouml;r nyheterna.';
 $lang['helpcategory'] = 'Visar endast nyheter i vald kategori. <strong>Anv&auml;nd * efter namnet f&ouml;r att visa underkategorier.</strong> Flera kategorier kan visas, anv&auml;nd kommatecken mellan varje. Om ingen specifik kategori anges s&aring; visas alla nyheter.';
 $lang['helpmoretext'] = 'Text som visas efter en artikels sammanfattning. Ett klick p&aring; den visar hela nyhetsartikeln. Om inget anges s&aring; visas &quot;more...&quot;.';
 $lang['helpsummarytemplate'] = 'Anv&auml;nd en specifik mall f&ouml;r att styra nyhetssammanfattningen. Mallen m&aring;ste finnas i mappen modules/News/templates.';
@@ -277,8 +271,8 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.1844854326557378000.1220712016.1229529495.1229534517.147';
-$lang['utmz'] = '156861353.1229373146.139.10.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/20|utmcmd=referral';
+$lang['utma'] = '156861353.120607462.1233740298.1239218099.1239222156.7';
+$lang['utmz'] = '156861353.1239218099.6.5.utmccn=(referral)|utmcsr=umearugby.se|utmcct=/admin/moduleinterface.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1229534517';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
