@@ -220,7 +220,7 @@ class Tree
 	*/
 	function &getChildren()
 	{
-		return $this->nodes->nodes;
+	  return $this->nodes->nodes;
 	}
 	
 	function &getFlatList()
@@ -397,33 +397,54 @@ class Tree_Node
         }
     }
 
-	/**
-	* Gets the underlying content of this node
-	*/
-	function &getContent()
-	{
-		//TODO: Lookup node in tree's list
-		//      Pull it from the db if it's not loaded already
-		//      Lots of room for optimization here
-		$content = null;
-		
-		$tree =& $this->getTree();
-		if (isset($tree->content[$this->getTag()]))
-		{
-			$content =& $tree->content[$this->getTag()];
-		}
-		else
-		{
-			//Basic one.  Just try to load it separately
-			//into our list.  Get the props, since a one timer
-			//will probably have some property shown
-			global $gCms;
-			$contentops =& $gCms->GetContentOperations();
-			$content =& $contentops->LoadContentFromId($this->getTag(), true);
-			$tree->content[$this->getTag()] =& $content;
-		}
-		return $content;
-	}
+
+    /**
+     * Gets the ID of this node
+     */
+    function getID()
+    {
+      return $this->getTag();
+    }
+
+    /**
+     * Gets the underlying content of this node
+     */
+    function &getContent($deep = false,$loadsiblings = true,$loadall = true)
+      {
+	$content = null;
+	
+	$tree =& $this->getTree();
+	if (isset($tree->content[$this->getTag()]))
+	  {
+	    $content =& $tree->content[$this->getTag()];
+	  }
+	else
+	  {
+	    // not in cache
+
+	    // find the parent node.
+	    $parent_node =& $this->getParent();
+	    if( !$loadsiblings || !$parent_node )
+	      {
+		// load the single node
+		global $gCms;
+		$contentops =& $gCms->GetContentOperations();
+		$content =& $contentops->LoadContentFromId($this->getTag(), $deep);
+		$tree->content[$this->getTag()] =& $content;
+	      }
+	    else
+	      {
+		$parent_node->getChildren($deep,$loadall);
+	      }
+	    
+	    // see if the object is cached now.
+	    if( isset($tree->content[$this->getTag()]) )
+	      {
+		$content =& $tree->content[$this->getTag()];
+	      }
+	  }
+	return $content;
+      }
     
     /**
     * Sets the tag data
@@ -620,7 +641,7 @@ class Tree_Node
 	  $result = false;
 	  foreach( $this->nodes->nodes as $onenode )
 	    {
-	      $contentobj =& $onenode->getContent();
+	      $contentobj =& $onenode->getContent(false,true);
 	      if( is_object($contentobj) )
                 {
 	          if( $contentobj->Active() && $contentobj->ShowInMenu() )
@@ -640,7 +661,7 @@ class Tree_Node
 	*
 	* @return array All of the child nodes
 	*/
-	function &getChildren()
+	function &getChildren($deep = false,$all = false)
 	{
 		//TODO: Write a bit here that pulls back all
 		//children in one shot if they're not already loaded
@@ -651,7 +672,8 @@ class Tree_Node
 			if (!isset($tree->content[$checkid])) {
 				global $gCms;
 				$contentops =& $gCms->GetContentOperations();
-				$contentops->LoadChildrenIntoTree($this->getTag(), $this->tree);
+				$contentops->LoadChildrenIntoTree($this->getTag(), $this->tree, 
+								  $deep, $all);
 			}
 		}
 		return $this->nodes->nodes;
