@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.admintheme.inc.php 5374 2008-12-30 16:32:11Z calguy1000 $
+#$Id: class.admintheme.inc.php 5774 2009-06-07 16:08:12Z calguy1000 $
 
 /**
  * Class for Admin Theme
@@ -300,7 +300,7 @@ class AdminTheme
                 check_permission($this->userid, 'Modify Any Page') ||
                 check_permission($this->userid, 'Add Pages') ||
                 check_permission($this->userid, 'Remove Pages') ||
-                check_permission($this->userid, 'Modify Page Structure')
+                check_permission($this->userid, 'Manage All Content')
         );
         $thisUserPages = author_pages($this->userid);
         if (count($thisUserPages) > 0)
@@ -697,9 +697,9 @@ class AdminTheme
 	    'home'=>array('url'=>'index.php','parent'=>'main',
 		    'title'=>$this->FixSpaces(lang('home')),
                     'description'=>'','show_in_menu'=>true),
-	    'dashboard'=>array('url'=>'dashboard.php','parent'=>'main',
-			       'title'=>$this->FixSpaces(lang('dashboard')),
-			       'description'=>'','show_in_menu'=>true),
+//	    'dashboard'=>array('url'=>'dashboard.php','parent'=>'main',
+//			       'title'=>$this->FixSpaces(lang('dashboard')),
+//			       'description'=>'','show_in_menu'=>true),
             'viewsite'=>array('url'=>'../index.php','parent'=>'main',
 			      'title'=>$this->FixSpaces(lang('viewsite')),
 			      'type'=>'external',
@@ -805,15 +805,15 @@ class AdminTheme
             'tags'=>array('url'=>'listtags.php','parent'=>'extensions',
                     'title'=>$this->FixSpaces(lang('tags')),
 			  'description'=>lang('tagdescription'),'show_in_menu'=>$this->HasPerm('taghelpPerms')),
+            'usertags'=>array('url'=>'listusertags.php','parent'=>'extensions',
+                    'title'=>$this->FixSpaces(lang('usertags')),
+                    'description'=>lang('usertagdescription'),'show_in_menu'=>$this->HasPerm('codeBlockPerms')),
             'eventhandlers'=>array('url'=>'eventhandlers.php','parent'=>'extensions',
                     'title'=>$this->FixSpaces(lang('eventhandlers')),
                     'description'=>lang('eventhandlerdescription'),'show_in_menu'=>$this->HasPerm('eventPerms')),
             'editeventhandler'=>array('url'=>'editevent.php','parent'=>'eventhandlers',
                     'title'=>$this->FixSpaces(lang('editeventhandler')),
                     'description'=>lang('editeventshandler'),'show_in_menu'=>false),
-            'usertags'=>array('url'=>'listusertags.php','parent'=>'extensions',
-                    'title'=>$this->FixSpaces(lang('usertags')),
-                    'description'=>lang('usertagdescription'),'show_in_menu'=>$this->HasPerm('codeBlockPerms')),
             'addusertag'=>array('url'=>'adduserplugin.php','parent'=>'usertags',
                     'title'=>$this->FixSpaces(lang('addusertag')),
                     'description'=>lang('addusertag'),'show_in_menu'=>false),
@@ -845,7 +845,7 @@ class AdminTheme
             'myprefs'=>array('url'=>'topmyprefs.php','parent'=>-1,
 			     'title'=>$this->FixSpaces(lang('myprefs')),
 			     'description'=>lang('myprefsdescription'),'show_in_menu'=>true),
-            'myaccount'=>array('url'=>'myedituser.php','parent'=>'myprefs',
+            'myaccount'=>array('url'=>'edituser.php','parent'=>'myprefs',
                     'title'=>$this->FixSpaces(lang('myaccount')),
                     'description'=>lang('myaccountdescription'),'show_in_menu'=>true),
             'preferences'=>array('url'=>'editprefs.php','parent'=>'myprefs',
@@ -1041,6 +1041,7 @@ class AdminTheme
 		$tmp = substr($this->breadcrumbs[$count-1]['url'],0,$pos).'?'.$this->query;
 		$this->breadcrumbs[$count-1]['url'] = $tmp;
 	      }
+	    unset($this->breadcrumbs[$count-1]['url']);
 	    if ($this->subtitle != '')
 	      {
 		$this->breadcrumbs[$count-1]['title'] .=  ': '.$this->subtitle;
@@ -1369,7 +1370,7 @@ class AdminTheme
 		global $gCms;
 		$config =& $gCms->GetConfig();
 ?><head>
-<meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-6 Ted Kulp. All rights reserved." />
+<meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-9 Ted Kulp. All rights reserved." />
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 <meta name="robots" content="noindex, nofollow" />
 <title><?php echo $this->title ?></title>
@@ -1776,19 +1777,20 @@ class AdminTheme
       global $gCms;
       $config =& $gCms->GetConfig();
       $wikiUrl = $config['wiki_url'];
-
-      if (FALSE == empty($_REQUEST['module'])  || FALSE == empty($_REQUEST['mact']))
-	{
-	  if (FALSE == empty($_REQUEST['module']))
-	    {
-	      $wikiUrl .= '/'.$_REQUEST['module'];
-	    }
-	  else
-	    {
-	      $wikiUrl .= '/'.substr($_REQUEST['mact'], 0, strpos($_REQUEST['mact'], ','));
-	    }
-	}
+      if ($wikiUrl !='none'){
+		      if (FALSE == empty($_REQUEST['module'])  || FALSE == empty($_REQUEST['mact']))
+			{
+			  if (FALSE == empty($_REQUEST['module']))
+			    {
+			      $wikiUrl .= '/'.$_REQUEST['module'];
+			    }
+			  else
+			    {
+			      $wikiUrl .= '/'.substr($_REQUEST['mact'], 0, strpos($_REQUEST['mact'], ','));
+			    }
+			}
       $wikiUrl .= '/Troubleshooting';
+      }//wiki check
       $image_error = $this->DisplayImage('icons/system/stop.gif', lang('error'),'','','systemicon');
       $output  = '<div class="pageerrorcontainer"';
       if (FALSE == empty($get_var))
@@ -1817,8 +1819,10 @@ class AdminTheme
 	{
 	  $output  .= $image_error.' '.$errors;
 	}
-      $output .= ' <a href="'.$wikiUrl.'" target="_blank">'.lang('troubleshooting').'</a></div></div>';
-      
+	 if ($wikiUrl !='none'){
+      $output .= ' <a href="'.$wikiUrl.'" target="_blank">'.lang('troubleshooting').'</a>';
+      }//wiki check
+      $output .= '</div></div>';
       return $output;
     }
     
